%define         pypi_name      yt
# we don't want to provide private python extension libs
%define _exclude_files_from_autoprov %{python3_sitearch}/.*\\.so

Name:           python-yt
Version:        4.3.0
Release:        %mkrel 1
Group:          Sciences/Astronomy
Summary:        An analysis and visualization toolkit for Astrophysical simulations
License:        GPLV3+
URL:            https://yt-project.org/
Source0:        https://pypi.io/packages/source/y/yt/yt-%{version}.tar.gz

BuildRequires:  pyproject-rpm-macros
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  hdf5-devel
BuildRequires:  pkgconfig(libpng)
BuildRequires:  libgomp-devel

%description
Yt is an analysis tool for astrophysical simulation datasets,
generated by simulation platforms like Enzo, Orion, FLASH, Nyx,
MAESTRO, ART and Ramses.  It's written in python and heavily leverages
both NumPy and Matplotlib for fast arrays and visualization,
respectively.

%package -n python3-yt
Summary:        An analysis and visualization toolkit for Astrophysical simulations
Group:          Development/Python
BuildRequires:  python3-devel
BuildRequires:  python3-cython
BuildRequires:  python3-setuptools
BuildRequires:  python3dist(ewah-bool-utils)
BuildRequires:  python3-numpy-devel
Requires:       python3-h5py
Requires:       python3-matplotlib
Requires:       python3-numpy
%{?python_provide:%python_provide python3-yt}

%description -n python3-yt
Yt is an analysis tool for astrophysical simulation datasets,
generated by simulation platforms like Enzo, Orion, FLASH, Nyx,
MAESTRO, ART and Ramses.  It's written in python and heavily leverages
both NumPy and Matplotlib for fast arrays and visualization,
respectively.

This is the python3 build of Yt.


%prep
%setup -q -n %{pypi_name}-%{version}
%autopatch -p1


%build
%pyproject_wheel


%install
%pyproject_install
%pyproject_save_files yt


%files -n python3-yt -f %{pyproject_files}
%doc CITATION COPYING.txt CREDITS
%{_bindir}/yt


%changelog
* Sun Dec 31 2023 daviddavid <daviddavid> 4.3.0-1.mga10
+ Revision: 2024771
- new version: 4.3.0
- rebuild for py3.12

* Fri Nov 25 2022 papoteur <papoteur> 4.1.1-2.mga9
+ Revision: 1911008
- fix requirement on matplotlib

* Fri Nov 11 2022 papoteur <papoteur> 4.1.1-1.mga9
+ Revision: 1905550
- new 4.1.1

* Fri Apr 01 2022 umeabot <umeabot> 3.4.1-10.mga9
+ Revision: 1838224
- Mageia 9 Mass Rebuild

* Thu Feb 17 2022 tv <tv> 3.4.1-9.mga9
+ Revision: 1778834
- Fix filelist for python-3.10
- Rebuild for python-3.10

* Mon Apr 19 2021 daviddavid <daviddavid> 3.4.1-8.mga9
+ Revision: 1717039
- rebuild for python 3.9

* Sat Jan 09 2021 daviddavid <daviddavid> 3.4.1-7.mga8
+ Revision: 1670055
- rebuild for new hdf5 1.10.7

* Sun Feb 16 2020 umeabot <umeabot> 3.4.1-6.mga8
+ Revision: 1533982
- Mageia 8 Mass Rebuild

* Thu Sep 26 2019 daviddavid <daviddavid> 3.4.1-5.mga8
+ Revision: 1446532
- add patch to fix linking issue
+ tv <tv>
- rebuild for python-3.8
- drop python2 subpkg

* Tue Jan 08 2019 tv <tv> 3.4.1-4.mga7
+ Revision: 1351848
- rebuild with python 3.7

* Sun Sep 23 2018 umeabot <umeabot> 3.4.1-3.mga7
+ Revision: 1300626
- Mageia 7 Mass Rebuild
+ kekepower <kekepower>
- Exclude python2-ipython as it doesn't exist

* Wed Apr 25 2018 kekepower <kekepower> 3.4.1-1.mga7
+ Revision: 1222384
- Update to version 3.4.1
- Rename python-yt to python2-yt
- Use python_provide

* Mon Sep 18 2017 tv <tv> 3.4.0-1.mga7
+ Revision: 1155259
- new release
+ pterjan <pterjan>
- Update to 3.3.5, even if it also doesn't build
- Rebuild for python 3.6

* Sat Dec 17 2016 eatdirt <eatdirt> 3.3.3-1.mga6
+ Revision: 1075821
- Upgrade to version 3.3.3 + python3 packaging

* Tue Feb 16 2016 umeabot <umeabot> 2.5.5-9.mga6
+ Revision: 962471
- Mageia 6 Mass Rebuild

* Tue Jul 21 2015 daviddavid <daviddavid> 2.5.5-8.mga6
+ Revision: 855909
- rebuild with new hdf5

* Wed Oct 15 2014 umeabot <umeabot> 2.5.5-7.mga5
+ Revision: 748111
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 2.5.5-6.mga5
+ Revision: 730046
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 2.5.5-5.mga5
+ Revision: 688443
- Mageia 5 Mass Rebuild
+ pterjan <pterjan>
- Rebuild for new Python

* Tue Oct 22 2013 umeabot <umeabot> 2.5.5-3.mga4
+ Revision: 544524
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 2.5.5-2.mga4
+ Revision: 499791
- Rebuild to add different pythonegg provides for python 2 and 3

* Mon Oct 07 2013 philippem <philippem> 2.5.5-1.mga4
+ Revision: 492721
- Update to 2.5.5

* Fri Jul 26 2013 joequant <joequant> 2.4-1.mga4
+ Revision: 458655
- change gomp openmp
- add openmpi
- uses freetype2
- add png
- add numpy to build requires
- imported package python-yt

